<?php
namespace Topalis\App\Entity;

use Topalis\Database\EntityManager;
use Topalis\Device\Entity\Device;

/**
 *
 *
 * @author Florian Pfitzer <pfitzer@w3p.cc>
 */
class AppStateEntityManager extends EntityManager
{
    /**
     * Find states for an app which are managed but not assigend to a device in the current config groups.
     * @param App $app
     *
     * @return AppState[]
     */
    public function findUnusedManaged(App $app)
    {
        $groups = array();
        foreach ($app->getConfigGroups() as $group) {
            $groups[] = $group->getId();
        }
        return $this->createQueryBuilder("s")
            ->select("s")
            ->join("s.device", "d")
            ->where("s.app = :app AND s.managed = 1 AND d.configGroup NOT IN (:groups)")
            ->setParameter("app", $app)
            ->setParameter("groups", implode(",", $groups))
            ->getQuery()
            ->getResult()
        ;
    }
}
